"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
var _exportNames = {
  useAccountUIState: true,
  useAccountUIActions: true,
  AccountUIStateContext: true,
  AccountUIActionContext: true,
  AccountActions: true
};
Object.defineProperty(exports, "AccountUIStateContext", {
  enumerable: true,
  get: function () {
    return _context.StateContext;
  }
});
Object.defineProperty(exports, "AccountUIActionContext", {
  enumerable: true,
  get: function () {
    return _context.ActionContext;
  }
});
Object.defineProperty(exports, "AccountActions", {
  enumerable: true,
  get: function () {
    return _dispatchActions.AccountActions;
  }
});
exports.useAccountUIActions = exports.useAccountUIState = void 0;

var _context = require("./context");

var _react = require("react");

var _types = require("./types");

Object.keys(_types).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (Object.prototype.hasOwnProperty.call(_exportNames, key)) return;
  if (key in exports && exports[key] === _types[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _types[key];
    }
  });
});

var _reducer = require("./reducer");

Object.keys(_reducer).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (Object.prototype.hasOwnProperty.call(_exportNames, key)) return;
  if (key in exports && exports[key] === _reducer[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _reducer[key];
    }
  });
});

var _dispatchActions = require("./dispatchActions");

/**
 * AccountUIStateContext and AccountUIActionContext provide access to global state and actions for account related information (login, forgot password, verify reset password code, etc.).
 *
 * @packageDocumentation
 * @module AccountUIContext
 * @preferred
 * @internal
 */

/**
 * Hook for using the global account state for account-related global [[AccountUIState]] state changes (i.e. login, forgot password, set password, verify reset code).
 *
 * @category Hooks
 */
const useAccountUIState = () => {
  const context = (0, _react.useContext)(_context.StateContext);

  if (context === null) {
    throw new Error('useAccountUIState must be used within an AccountUIStateContext');
  }

  return context;
};
/**
 * Hook for using the global [[AccountUIActions]] actions (i.e. logIn, forgotPassword, etc.) which change the global [[AccountUIState]].
 *
 * @category Hooks
 */


exports.useAccountUIState = useAccountUIState;

const useAccountUIActions = () => {
  const context = (0, _react.useContext)(_context.ActionContext);

  if (context === null) {
    throw new Error('useAccountUIActions must be used within an AccountUIActionContext');
  }

  return context;
};

exports.useAccountUIActions = useAccountUIActions;
//# sourceMappingURL=index.js.map